<?php // $Id$ 
      // enrol_internal.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['description'] = 'ɸŪʥ桼ϿˡǤϿ硢פ2Ĥˡޤ
<ul>
<li>դޤϴԤΥ˥塼ˤ󥯤ѤƼưϿ롣</li>
<li>ˤϡϿפȤѥɤꤹ뤳ȤǤޤΥΤäƤͤïǤ⼫饳˻ä뤳ȤǤޤ</li>
</ul>';
$string['enrolname'] = 'Ͽ';;

?>
